@@ -106,7 +106,7 @@ enum death {
 #define PO_BOW (PO_FIRST_WEAPON + 4)
 #define PO_CROSSBOW (PO_FIRST_WEAPON + 5)
 #define PO_LAST_WEAPON PO_CROSSBOW
-#define PO_POT_HEAL 6
+#define PO_POT_HEAL (PO_LAST_WEAPON + 1)
 #define PO_FIRST_POTION PO_POT_HEAL
 #define PO_POT_POISON (PO_FIRST_POTION + 1)
 #define PO_POT_BODY (PO_FIRST_POTION + 2)
@@ -293,9 +293,9 @@ extern struct permon permons[100];
 
 /* XXX rng.c data and funcs */
 #define RNG_MAX 0xFFFFFFFFu
-extern unsigned long rng_state[5];
-extern unsigned long saved_state[5];
-extern unsigned long rng(void);
+extern unsigned int rng_state[5];
+extern unsigned int saved_state[5];
+extern unsigned int rng(void);
 extern void rng_init(void);
 
 /* XXX u.c data and funcs */
