@@ -77,9 +77,11 @@ void save_game(void)
 	 * flags as well as at-exploration flags, the at-generation flags
 	 * will be stored in a separate array. */
 	fwrite(mapflags, DUN_SIZE, DUN_SIZE * sizeof (int), fp);
-	/* Write out the permanent monster/object data. This is hideously
-	 * wasteful, but it makes handling flavours much easier... */
-	fwrite(permons, 100, sizeof (struct permon), fp);
+	/* Write out the permanent object data. This is hideously
+	 * wasteful (and guarantees savefile breakage at version-up), but
+	 * it makes handling flavours much easier... */
+	/* FIX: We no longer write out the permons data, since none of it
+	 * changes at the moment. */
 	fwrite(permobjs, 100, sizeof (struct permobj), fp);
 	/* Write out the dynamic monster/object arrays. */
 	fwrite(monsters, 100, sizeof (struct mon), fp);
@@ -256,6 +258,8 @@ int do_command(enum game_cmd cmd)
 		if (i >= 0)
 		{
 			u.armour = u.inventory[i];
+			/* Fix (1.1): Magic armour now auto-IDs when worn. */
+			permobjs[objects[u.armour].obj_id].known = 1;
 			recalc_defence();
 			print_msg("You change your armour.\n");
 			return 1;
